Skip to contents

Retrieve location of FINEMAP executable. First checks if finemap is already available on the system PATH (e.g. installed via conda install -c bioconda finemap), then falls back to downloading the binary from GitHub releases. On Apple Silicon Macs, automatically sets up x86_64 dynamic libraries via FINEMAP_setup_dylibs.

Usage

FINEMAP_find_executable(
  FINEMAP_path = NULL,
  OS = NULL,
  save_dir = file.path(tools::R_user_dir(package = "echofinemap", which = "cache"),
    "FINEMAP"),
  version = package_version("1.4.1"),
  verbose = TRUE
)

Examples

if (FALSE) { # \dontrun{
FINEMAP_path <- echofinemap:::FINEMAP_find_executable(version="1.3.1")
} # }