Conduct statistical fine-mapping with Approximate Bayes Factor (ABF) via finemap.abf.
Usage
ABF(
dat,
credset_thresh = 0.95,
compute_n = "ldsc",
sdY = NULL,
case_control = TRUE,
verbose = TRUE
)Arguments
- dat
Fine-mapping results data.
- credset_thresh
The minimum mean Posterior Probability (across all fine-mapping methods used) of SNPs to be included in the "mean.CS" column.
- compute_n
How to compute per-SNP sample size (new column "N").
If the column "N" is already present indat, this column will be used to extract per-SNP sample sizes and the argumentcompute_nwill be ignored.
If the column "N" is not present indat, one of the following options can be supplied tocompute_n:0N will not be computed.
>0If any number >0 is provided, that value will be set as N for every row. **Note**: Computing N this way is incorrect and should be avoided if at all possible.
"sum"N will be computed as: cases (N_CAS) + controls (N_CON), so long as both columns are present.
"ldsc"N will be computed as effective sample size: Neff =(N_CAS+N_CON)*(N_CAS/(N_CAS+N_CON)) / mean((N_CAS/(N_CAS+N_CON))(N_CAS+N_CON)==max(N_CAS+N_CON)).
"giant"N will be computed as effective sample size: Neff = 2 / (1/N_CAS + 1/N_CON).
"metal"N will be computed as effective sample size: Neff = 4 / (1/N_CAS + 1/N_CON).
- sdY
Standard deviation of quantitative trait.
- case_control
Whether the summary statistics come from a case-control study (e.g. a GWAS of having Alzheimer's Disease or not) (
TRUE) or a quantitative study (e.g. a GWAS of height, or an eQTL) (FALSE).- verbose
Print messages.
Examples
if (FALSE) { # \dontrun{
dat <- echodata::LRRK2
dat2 <- echofinemap::ABF(dat=dat)
} # }