Test that the FINEMAP binary can actually execute on the current system. On Apple Silicon Macs, the x86_64 FINEMAP binary requires Rosetta 2 and x86_64 versions of several dynamic libraries (zstd, gcc, libomp).
Test that the FINEMAP binary can actually execute on the current system. On Apple Silicon Macs, the x86_64 FINEMAP binary requires Rosetta 2 and x86_64 versions of several dynamic libraries (zstd, gcc, libomp).