Munge summary statistics using the PolyFun implementation of the LDSSC
munge sum stats python script (munge_polyfun_sumstats.py).
NOTE: This script is kept only for documentation purposes.
Please use
MungeSumstats
instead as it is far more robust.
Usage
POLYFUN_munge_summ_stats(
fullSS_path,
polyfun_path = NULL,
locus_dir = tempdir(),
sample_size = NULL,
min_INFO = 0,
min_MAF = 0.001,
chi2_cutoff = 30,
keep_hla = FALSE,
no_neff = FALSE,
force_new_munge = FALSE,
conda_env = "echoR_mini",
verbose = TRUE
)Source
fullSS_path <- echodata::example_fullSS()
munged_path <- POLYFUN_munge_summ_stats(fullSS_path=fullSS_path)
Arguments
- fullSS_path
Path to the full summary statistics file (GWAS or QTL) that you want to fine-map. It is usually best to provide the absolute path rather than the relative path.
- polyfun_path
[Optional] Path to PolyFun directory where all the executables and reference data are stored. Will be automatically installed if set to
NULL(default).- locus_dir
Locus-specific directory to store results in.
- conda_env
Conda environment to use.
- verbose
Print messages.